@@ -56,6 +56,7 @@ struct _NautilusBatchRenameDialog
     GtkWidget *scrolled_window;
     GtkWidget *numbering_order_popover;
     GtkWidget *numbering_order_button;
+    GtkWidget *numbering_revealer;
     GtkWidget *conflict_box;
     GtkWidget *conflict_label;
     GtkWidget *conflict_down;
@@ -139,7 +140,7 @@ change_numbering_order (GSimpleAction *action,
                                  gettext (sorts_constants[i].label));
             dialog->selection = nautilus_batch_rename_dialog_sort (dialog->selection,
                                                                    sorts_constants[i].sort_mode,
-                                                                   NULL);
+                                                                   dialog->create_date);
           break;
         }
     }
@@ -196,7 +197,7 @@ add_tag (NautilusBatchRenameDialog *self,
      */
     gtk_editable_insert_text (GTK_EDITABLE (self->name_entry),
                               tag_text_representation,
-                              g_utf8_strlen (tag_text_representation, -1),
+                              strlen (tag_text_representation),
                               &cursor_position);
     tag_data->just_added = FALSE;
     gtk_editable_set_position (GTK_EDITABLE (self->name_entry), cursor_position);
@@ -378,6 +379,10 @@ split_entry_text (NautilusBatchRenameDialog *self,
         {
             result = g_list_prepend (result, normal_text);
         }
+        else
+        {
+            g_string_free (normal_text, TRUE);
+        }
 
         for (l = tag_info_keys; l != NULL; l = l->next)
         {
@@ -404,6 +409,10 @@ split_entry_text (NautilusBatchRenameDialog *self,
     {
         result = g_list_prepend (result, normal_text);
     }
+    else
+    {
+        g_string_free (normal_text, TRUE);
+    }
 
     result = g_list_reverse (result);
 
@@ -625,7 +634,6 @@ create_original_name_row_for_label (NautilusBatchRenameDialog *dialog,
     gtk_label_set_xalign (GTK_LABEL (label_old), 0.0);
     gtk_widget_set_hexpand (label_old, TRUE);
     gtk_widget_set_margin_start (label_old, ROW_MARGIN_START);
-
     gtk_label_set_ellipsize (GTK_LABEL (label_old), PANGO_ELLIPSIZE_END);
 
     dialog->listbox_labels_old = g_list_prepend (dialog->listbox_labels_old, label_old);
@@ -652,7 +660,6 @@ create_result_row_for_label (NautilusBatchRenameDialog *dialog,
     gtk_label_set_xalign (GTK_LABEL (label_new), 0.0);
     gtk_widget_set_hexpand (label_new, TRUE);
     gtk_widget_set_margin_start (label_new, ROW_MARGIN_START);
-
     gtk_label_set_ellipsize (GTK_LABEL (label_new), PANGO_ELLIPSIZE_END);
 
     dialog->listbox_labels_new = g_list_prepend (dialog->listbox_labels_new, label_new);
@@ -728,6 +735,7 @@ prepare_batch_rename (NautilusBatchRenameDialog *dialog)
     if (dialog->conflict_cancellable)
     {
         g_cancellable_cancel (dialog->conflict_cancellable);
+        g_clear_object (&dialog->conflict_cancellable);
     }
 
     gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -747,6 +755,7 @@ batch_rename_dialog_on_response (NautilusBatchRenameDialog *dialog,
         if (dialog->conflict_cancellable)
         {
             g_cancellable_cancel (dialog->conflict_cancellable);
+            g_clear_object (&dialog->conflict_cancellable);
         }
 
         gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -869,6 +878,7 @@ select_nth_conflict (NautilusBatchRenameDialog *dialog)
                          display_text->str);
 
     g_string_free (conflict_file_name, TRUE);
+    g_string_free (display_text, TRUE);
 }
 
 static void
@@ -971,6 +981,7 @@ update_listbox (NautilusBatchRenameDialog *dialog)
     gchar *old_name;
     GtkLabel *label;
     GString *new_name;
+    gboolean empty_name = FALSE;
 
     for (l1 = dialog->new_names, l2 = dialog->listbox_labels_new; l1 != NULL && l2 != NULL; l1 = l1->next, l2 = l2->next)
     {
@@ -978,6 +989,12 @@ update_listbox (NautilusBatchRenameDialog *dialog)
         new_name = l1->data;
 
         gtk_label_set_label (label, new_name->str);
+        gtk_widget_set_tooltip_text(GTK_WIDGET (label), new_name->str);
+
+        if (g_strcmp0 (new_name->str, "") == 0)
+        {
+            empty_name = TRUE;
+        }
     }
 
     for (l1 = dialog->selection, l2 = dialog->listbox_labels_old; l1 != NULL && l2 != NULL; l1 = l1->next, l2 = l2->next)
@@ -986,6 +1003,7 @@ update_listbox (NautilusBatchRenameDialog *dialog)
         file = NAUTILUS_FILE (l1->data);
 
         old_name = nautilus_file_get_name (file);
+        gtk_widget_set_tooltip_text(GTK_WIDGET (label), old_name);
 
         if (dialog->mode == NAUTILUS_BATCH_RENAME_DIALOG_FORMAT)
         {
@@ -1005,6 +1023,13 @@ update_listbox (NautilusBatchRenameDialog *dialog)
 
     update_rows_height (dialog);
 
+    if (empty_name)
+    {
+        gtk_widget_set_sensitive (dialog->rename_button, FALSE);
+
+        return;
+    }
+
     /* check if there are name conflicts and display them if they exist */
     if (dialog->duplicates != NULL)
     {
@@ -1167,7 +1192,7 @@ check_conflict_for_files (NautilusBatchRenameDialog *dialog,
         if (!have_conflict)
         {
             tag_present = g_hash_table_lookup (names_conflicts_table, new_name->str) != NULL;
-            same_parent_directory = g_strcmp0 (nautilus_file_get_parent_uri (file), current_directory) == 0;
+            same_parent_directory = g_strcmp0 (parent_uri, current_directory) == 0;
 
             if (tag_present && same_parent_directory)
             {
@@ -1215,6 +1240,7 @@ on_file_names_list_has_duplicates (GObject      *object,
 
     if (!success)
     {
+        g_clear_error (&error);
         return;
     }
 
@@ -1226,6 +1252,7 @@ on_file_names_list_has_duplicates (GObject      *object,
 typedef struct
 {
     GList *directories;
+    NautilusDirectory *current_directory;
     GMutex wait_ready_mutex;
     GCond wait_ready_condition;
     gboolean directory_conflicts_ready;
@@ -1256,6 +1283,20 @@ on_directory_conflicts_ready (NautilusDirectory *conflict_directory,
     g_mutex_unlock (&task_data->wait_ready_mutex);
 }
 
+static gboolean
+check_conflicts_on_main_thread (gpointer user_data)
+{
+    GTask *task = (GTask *) user_data;
+    CheckConflictsData *task_data = g_task_get_task_data (task);
+
+    nautilus_directory_call_when_ready (task_data->current_directory,
+                                        NAUTILUS_FILE_ATTRIBUTE_INFO,
+                                        TRUE,
+                                        on_directory_conflicts_ready,
+                                        task);
+    return FALSE;
+}
+
 static void
 file_names_list_has_duplicates_async_thread (GTask        *task,
                                              gpointer      object,
@@ -1264,10 +1305,8 @@ file_names_list_has_duplicates_async_thread (GTask        *task,
 {
     NautilusBatchRenameDialog *self;
     CheckConflictsData *task_data;
-    NautilusDirectory *conflict_directory;
     GList *directories;
     GList *l;
-    const gchar *directory_conflict_uri = NULL;
 
     self = g_task_get_source_object (task);
     task_data = g_task_get_task_data (task);
@@ -1282,20 +1321,19 @@ file_names_list_has_duplicates_async_thread (GTask        *task,
     {
         if (g_task_return_error_if_cancelled (task))
         {
+            nautilus_directory_list_free (directories);
             return;
         }
 
         g_mutex_lock (&task_data->wait_ready_mutex);
         task_data->directory_conflicts_ready = FALSE;
 
-        directory_conflict_uri = l->data;
-        conflict_directory = nautilus_directory_get_by_uri (directory_conflict_uri);
 
-        nautilus_directory_call_when_ready (conflict_directory,
-                                            NAUTILUS_FILE_ATTRIBUTE_INFO,
-                                            TRUE,
-                                            on_directory_conflicts_ready,
-                                            task);
+        task_data->current_directory = l->data;
+        /* NautilusDirectory and NautilusFile are not thread safe, we need to call
+         * them on the main thread.
+         */
+        g_main_context_invoke (NULL, check_conflicts_on_main_thread, task);
 
         /* We need to block this thread until the call_when_ready call is done,
          * if not the GTask would finalize. */
@@ -1307,10 +1345,10 @@ file_names_list_has_duplicates_async_thread (GTask        *task,
 
         g_mutex_unlock (&task_data->wait_ready_mutex);
 
-        nautilus_directory_unref (conflict_directory);
     }
 
   g_task_return_boolean (task, TRUE);
+  nautilus_directory_list_free (directories);
 }
 
 static void
@@ -1323,6 +1361,8 @@ destroy_conflicts_task_data (gpointer data)
         g_list_free (task_data->directories);
     }
 
+    g_free (task_data);
+
     g_mutex_clear (&task_data->wait_ready_mutex);
     g_cond_clear (&task_data->wait_ready_condition);
 }
@@ -1478,6 +1518,7 @@ update_display_text (NautilusBatchRenameDialog *dialog)
     if (dialog->conflict_cancellable != NULL)
     {
         g_cancellable_cancel (dialog->conflict_cancellable);
+        g_clear_object (&dialog->conflict_cancellable);
     }
 
     if(dialog->selection == NULL)
@@ -1498,13 +1539,11 @@ update_display_text (NautilusBatchRenameDialog *dialog)
 
     if (!numbering_tag_is_some_added (dialog))
     {
-        gtk_label_set_label (GTK_LABEL (dialog->numbering_label), "");
-        gtk_widget_hide (dialog->numbering_order_button);
+        gtk_revealer_set_reveal_child(GTK_REVEALER(dialog->numbering_revealer), FALSE);
     }
     else
     {
-        gtk_label_set_label (GTK_LABEL (dialog->numbering_label), _("Automatic Numbering Order"));
-        gtk_widget_show (dialog->numbering_order_button);
+        gtk_revealer_set_reveal_child(GTK_REVEALER(dialog->numbering_revealer), TRUE);
     }
 
     dialog->new_names = batch_rename_dialog_get_new_names (dialog);
@@ -1999,7 +2038,7 @@ nautilus_batch_rename_dialog_finalize (GObject *object)
     if (dialog->checking_conflicts)
     {
         g_cancellable_cancel (dialog->conflict_cancellable);
-        g_object_unref (dialog->conflict_cancellable);
+        g_clear_object (&dialog->conflict_cancellable);
     }
 
     g_list_free (dialog->original_name_listbox_rows);
@@ -2022,6 +2061,7 @@ nautilus_batch_rename_dialog_finalize (GObject *object)
             }
         }
 
+        g_string_free (file_metadata->file_name, TRUE);
         g_free (file_metadata);
     }
 
@@ -2033,6 +2073,13 @@ nautilus_batch_rename_dialog_finalize (GObject *object)
     g_list_free_full (dialog->new_names, string_free);
     g_list_free_full (dialog->duplicates, conflict_data_free);
 
+    nautilus_file_list_free (dialog->selection);
+    nautilus_directory_unref (dialog->directory);
+
+    g_object_unref (dialog->size_group);
+
+    g_hash_table_destroy (dialog->tag_info_table);
+
     G_OBJECT_CLASS (nautilus_batch_rename_dialog_parent_class)->finalize (object);
 }
 
@@ -2067,6 +2114,7 @@ nautilus_batch_rename_dialog_class_init (NautilusBatchRenameDialogClass *klass)
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, scrolled_window);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, numbering_order_popover);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, numbering_order_button);
+    gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, numbering_revealer);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, numbering_order_menu);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, conflict_box);
     gtk_widget_class_bind_template_child (widget_class, NautilusBatchRenameDialog, conflict_label);
@@ -2101,8 +2149,8 @@ nautilus_batch_rename_dialog_new (GList             *selection,
 
     dialog = g_object_new (NAUTILUS_TYPE_BATCH_RENAME_DIALOG, "use-header-bar", TRUE, NULL);
 
-    dialog->selection = selection;
-    dialog->directory = directory;
+    dialog->selection = nautilus_file_list_copy (selection);
+    dialog->directory = nautilus_directory_ref (directory);
     dialog->window = window;
 
     gtk_window_set_transient_for (GTK_WINDOW (dialog),
