@@ -573,8 +573,7 @@ nautilus_files_view_drop_proxy_received_uris (NautilusFilesView *view,
     }
 
     nautilus_clipboard_clear_if_colliding_uris (GTK_WIDGET (view),
-                                                source_uri_list,
-                                                nautilus_files_view_get_copied_files_atom (view));
+                                                source_uri_list);
 
     nautilus_files_view_move_copy_items (view, source_uri_list, NULL,
                                          target_uri != NULL ? target_uri : container_uri,
